"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.card.v1.common_pb2
import bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TopicCardType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _TopicCardTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TopicCardType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ILLEGAL_TYPE: _TopicCardType.ValueType  # 0
    """"""

    DYNAMIC: _TopicCardType.ValueType  # 1
    """"""

    FOLD: _TopicCardType.ValueType  # 2
    """"""

class TopicCardType(_TopicCardType, metaclass=_TopicCardTypeEnumTypeWrapper):
    """"""
    pass

ILLEGAL_TYPE: TopicCardType.ValueType  # 0
""""""

DYNAMIC: TopicCardType.ValueType  # 1
""""""

FOLD: TopicCardType.ValueType  # 2
""""""

global___TopicCardType = TopicCardType


class DetailsTopInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOPIC_INFO_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    STATS_DESC_FIELD_NUMBER: builtins.int
    HAS_CREATE_JURISDICTION_FIELD_NUMBER: builtins.int
    OPERATION_CONTENT_FIELD_NUMBER: builtins.int
    HEAD_IMG_URL_FIELD_NUMBER: builtins.int
    HEAD_IMG_BACKCOLOR_FIELD_NUMBER: builtins.int
    WORD_COLOR_FIELD_NUMBER: builtins.int
    @property
    def topic_info(self) -> global___TopicInfo:
        """"""
        pass
    @property
    def user(self) -> global___User:
        """"""
        pass
    stats_desc: typing.Text
    """"""

    has_create_jurisdiction: builtins.bool
    """"""

    @property
    def operation_content(self) -> global___OperationContent:
        """"""
        pass
    head_img_url: typing.Text
    """"""

    head_img_backcolor: typing.Text
    """"""

    word_color: builtins.int
    """"""

    def __init__(self,
        *,
        topic_info: typing.Optional[global___TopicInfo] = ...,
        user: typing.Optional[global___User] = ...,
        stats_desc: typing.Text = ...,
        has_create_jurisdiction: builtins.bool = ...,
        operation_content: typing.Optional[global___OperationContent] = ...,
        head_img_url: typing.Text = ...,
        head_img_backcolor: typing.Text = ...,
        word_color: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation_content",b"operation_content","topic_info",b"topic_info","user",b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_create_jurisdiction",b"has_create_jurisdiction","head_img_backcolor",b"head_img_backcolor","head_img_url",b"head_img_url","operation_content",b"operation_content","stats_desc",b"stats_desc","topic_info",b"topic_info","user",b"user","word_color",b"word_color"]) -> None: ...
global___DetailsTopInfo = DetailsTopInfo

class FoldCardItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_SHOW_FOLD_FIELD_NUMBER: builtins.int
    FOLD_COUNT_FIELD_NUMBER: builtins.int
    CARD_SHOW_DESC_FIELD_NUMBER: builtins.int
    FOLD_DESC_FIELD_NUMBER: builtins.int
    is_show_fold: builtins.int
    """"""

    fold_count: builtins.int
    """"""

    card_show_desc: typing.Text
    """"""

    fold_desc: typing.Text
    """"""

    def __init__(self,
        *,
        is_show_fold: builtins.int = ...,
        fold_count: builtins.int = ...,
        card_show_desc: typing.Text = ...,
        fold_desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_show_desc",b"card_show_desc","fold_count",b"fold_count","fold_desc",b"fold_desc","is_show_fold",b"is_show_fold"]) -> None: ...
global___FoldCardItem = FoldCardItem

class FunctionalCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CAPSULES_FIELD_NUMBER: builtins.int
    TRAFFIC_CARD_FIELD_NUMBER: builtins.int
    GAME_CARD_FIELD_NUMBER: builtins.int
    @property
    def capsules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicCapsule]:
        """"""
        pass
    @property
    def traffic_card(self) -> global___TrafficCard:
        """"""
        pass
    @property
    def game_card(self) -> global___GameCard:
        """"""
        pass
    def __init__(self,
        *,
        capsules: typing.Optional[typing.Iterable[global___TopicCapsule]] = ...,
        traffic_card: typing.Optional[global___TrafficCard] = ...,
        game_card: typing.Optional[global___GameCard] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["game_card",b"game_card","traffic_card",b"traffic_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capsules",b"capsules","game_card",b"game_card","traffic_card",b"traffic_card"]) -> None: ...
global___FunctionalCard = FunctionalCard

class GameCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GAME_ID_FIELD_NUMBER: builtins.int
    GAME_ICON_FIELD_NUMBER: builtins.int
    GAME_NAME_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    GAME_TAGS_FIELD_NUMBER: builtins.int
    NOTICE_FIELD_NUMBER: builtins.int
    GAME_LINK_FIELD_NUMBER: builtins.int
    game_id: builtins.int
    """"""

    game_icon: typing.Text
    """"""

    game_name: typing.Text
    """"""

    score: typing.Text
    """"""

    game_tags: typing.Text
    """"""

    notice: typing.Text
    """"""

    game_link: typing.Text
    """"""

    def __init__(self,
        *,
        game_id: builtins.int = ...,
        game_icon: typing.Text = ...,
        game_name: typing.Text = ...,
        score: typing.Text = ...,
        game_tags: typing.Text = ...,
        notice: typing.Text = ...,
        game_link: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["game_icon",b"game_icon","game_id",b"game_id","game_link",b"game_link","game_name",b"game_name","game_tags",b"game_tags","notice",b"notice","score",b"score"]) -> None: ...
global___GameCard = GameCard

class InlineProgressBar(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ICON_DRAG_FIELD_NUMBER: builtins.int
    ICON_DRAG_HASH_FIELD_NUMBER: builtins.int
    ICON_STOP_FIELD_NUMBER: builtins.int
    ICON_STOP_HASH_FIELD_NUMBER: builtins.int
    icon_drag: typing.Text
    """"""

    icon_drag_hash: typing.Text
    """"""

    icon_stop: typing.Text
    """"""

    icon_stop_hash: typing.Text
    """"""

    def __init__(self,
        *,
        icon_drag: typing.Text = ...,
        icon_drag_hash: typing.Text = ...,
        icon_stop: typing.Text = ...,
        icon_stop_hash: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_drag",b"icon_drag","icon_drag_hash",b"icon_drag_hash","icon_stop",b"icon_stop","icon_stop_hash",b"icon_stop_hash"]) -> None: ...
global___InlineProgressBar = InlineProgressBar

class LargeCoverInline(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON2_FIELD_NUMBER: builtins.int
    RIGHT_TOP_LIVE_BADGE_FIELD_NUMBER: builtins.int
    EXTRA_URI_FIELD_NUMBER: builtins.int
    INLINE_PROGRESS_BAR_FIELD_NUMBER: builtins.int
    TOPIC_THREE_POINT_FIELD_NUMBER: builtins.int
    COVER_LEFT_DESC_FIELD_NUMBER: builtins.int
    HIDE_DANMU_SWITCH_FIELD_NUMBER: builtins.int
    DISABLE_DANMU_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    DURATION_TEXT_FIELD_NUMBER: builtins.int
    RELATION_DATA_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    cover_left_text1: typing.Text
    """"""

    cover_left_icon1: builtins.int
    """"""

    cover_left_text2: typing.Text
    """"""

    cover_left_icon2: builtins.int
    """"""

    @property
    def right_top_live_badge(self) -> global___RightTopLiveBadge:
        """"""
        pass
    extra_uri: typing.Text
    """"""

    @property
    def inline_progress_bar(self) -> global___InlineProgressBar:
        """"""
        pass
    @property
    def topic_three_point(self) -> global___TopicThreePoint:
        """"""
        pass
    cover_left_desc: typing.Text
    """"""

    hide_danmu_switch: builtins.bool
    """"""

    disable_danmu: builtins.bool
    """"""

    can_play: builtins.int
    """"""

    duration_text: typing.Text
    """"""

    @property
    def relation_data(self) -> global___RelationData:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        cover_left_text1: typing.Text = ...,
        cover_left_icon1: builtins.int = ...,
        cover_left_text2: typing.Text = ...,
        cover_left_icon2: builtins.int = ...,
        right_top_live_badge: typing.Optional[global___RightTopLiveBadge] = ...,
        extra_uri: typing.Text = ...,
        inline_progress_bar: typing.Optional[global___InlineProgressBar] = ...,
        topic_three_point: typing.Optional[global___TopicThreePoint] = ...,
        cover_left_desc: typing.Text = ...,
        hide_danmu_switch: builtins.bool = ...,
        disable_danmu: builtins.bool = ...,
        can_play: builtins.int = ...,
        duration_text: typing.Text = ...,
        relation_data: typing.Optional[global___RelationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base","inline_progress_bar",b"inline_progress_bar","relation_data",b"relation_data","right_top_live_badge",b"right_top_live_badge","topic_three_point",b"topic_three_point"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base",b"base","can_play",b"can_play","cover_left_desc",b"cover_left_desc","cover_left_icon1",b"cover_left_icon1","cover_left_icon2",b"cover_left_icon2","cover_left_text1",b"cover_left_text1","cover_left_text2",b"cover_left_text2","disable_danmu",b"disable_danmu","duration_text",b"duration_text","extra_uri",b"extra_uri","hide_danmu_switch",b"hide_danmu_switch","inline_progress_bar",b"inline_progress_bar","relation_data",b"relation_data","right_top_live_badge",b"right_top_live_badge","topic_three_point",b"topic_three_point"]) -> None: ...
global___LargeCoverInline = LargeCoverInline

class LiveBadgeResource(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    ANIMATION_URL_FIELD_NUMBER: builtins.int
    ANIMATION_URL_HASH_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_LIGHT_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    ALPHA_LIGHT_FIELD_NUMBER: builtins.int
    ALPHA_NIGHT_FIELD_NUMBER: builtins.int
    FONT_COLOR_FIELD_NUMBER: builtins.int
    text: typing.Text
    """"""

    animation_url: typing.Text
    """"""

    animation_url_hash: typing.Text
    """"""

    background_color_light: typing.Text
    """"""

    background_color_night: typing.Text
    """"""

    alpha_light: builtins.int
    """"""

    alpha_night: builtins.int
    """"""

    font_color: typing.Text
    """"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        animation_url: typing.Text = ...,
        animation_url_hash: typing.Text = ...,
        background_color_light: typing.Text = ...,
        background_color_night: typing.Text = ...,
        alpha_light: builtins.int = ...,
        alpha_night: builtins.int = ...,
        font_color: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alpha_light",b"alpha_light","alpha_night",b"alpha_night","animation_url",b"animation_url","animation_url_hash",b"animation_url_hash","background_color_light",b"background_color_light","background_color_night",b"background_color_night","font_color",b"font_color","text",b"text"]) -> None: ...
global___LiveBadgeResource = LiveBadgeResource

class OperationCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LARGE_COVER_INLINE_FIELD_NUMBER: builtins.int
    @property
    def large_cover_inline(self) -> global___LargeCoverInline:
        """"""
        pass
    def __init__(self,
        *,
        large_cover_inline: typing.Optional[global___LargeCoverInline] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card",b"card","large_cover_inline",b"large_cover_inline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card",b"card","large_cover_inline",b"large_cover_inline"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["card",b"card"]) -> typing.Optional[typing_extensions.Literal["large_cover_inline"]]: ...
global___OperationCard = OperationCard

class OperationContent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OPERATION_CARD_FIELD_NUMBER: builtins.int
    @property
    def operation_card(self) -> global___OperationCard:
        """"""
        pass
    def __init__(self,
        *,
        operation_card: typing.Optional[global___OperationCard] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation_card",b"operation_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation_card",b"operation_card"]) -> None: ...
global___OperationContent = OperationContent

class RelationData(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_FAV_FIELD_NUMBER: builtins.int
    IS_COIN_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_LIKE_FIELD_NUMBER: builtins.int
    LIKE_COUNT_FIELD_NUMBER: builtins.int
    is_fav: builtins.bool
    """"""

    is_coin: builtins.bool
    """"""

    is_follow: builtins.bool
    """"""

    is_like: builtins.bool
    """"""

    like_count: builtins.int
    """"""

    def __init__(self,
        *,
        is_fav: builtins.bool = ...,
        is_coin: builtins.bool = ...,
        is_follow: builtins.bool = ...,
        is_like: builtins.bool = ...,
        like_count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_coin",b"is_coin","is_fav",b"is_fav","is_follow",b"is_follow","is_like",b"is_like","like_count",b"like_count"]) -> None: ...
global___RelationData = RelationData

class RightTopLiveBadge(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIVE_STATUS_FIELD_NUMBER: builtins.int
    IN_LIVE_FIELD_NUMBER: builtins.int
    LIVE_STATS_DESC_FIELD_NUMBER: builtins.int
    live_status: builtins.int
    """"""

    @property
    def in_live(self) -> global___LiveBadgeResource:
        """"""
        pass
    live_stats_desc: typing.Text
    """"""

    def __init__(self,
        *,
        live_status: builtins.int = ...,
        in_live: typing.Optional[global___LiveBadgeResource] = ...,
        live_stats_desc: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["in_live",b"in_live"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["in_live",b"in_live","live_stats_desc",b"live_stats_desc","live_status",b"live_status"]) -> None: ...
global___RightTopLiveBadge = RightTopLiveBadge

class SortContent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SORT_BY_FIELD_NUMBER: builtins.int
    SORT_NAME_FIELD_NUMBER: builtins.int
    sort_by: builtins.int
    """"""

    sort_name: typing.Text
    """"""

    def __init__(self,
        *,
        sort_by: builtins.int = ...,
        sort_name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sort_by",b"sort_by","sort_name",b"sort_name"]) -> None: ...
global___SortContent = SortContent

class ThreePointItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    jump_url: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        jump_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_url",b"jump_url","title",b"title"]) -> None: ...
global___ThreePointItem = ThreePointItem

class TopicActivities(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACTIVITY_FIELD_NUMBER: builtins.int
    ACT_LIST_TITLE_FIELD_NUMBER: builtins.int
    @property
    def activity(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicActivity]:
        """"""
        pass
    act_list_title: typing.Text
    """"""

    def __init__(self,
        *,
        activity: typing.Optional[typing.Iterable[global___TopicActivity]] = ...,
        act_list_title: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_list_title",b"act_list_title","activity",b"activity"]) -> None: ...
global___TopicActivities = TopicActivities

class TopicActivity(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """"""

    activity_name: typing.Text
    """"""

    jump_url: typing.Text
    """"""

    icon_url: typing.Text
    """"""

    def __init__(self,
        *,
        activity_id: builtins.int = ...,
        activity_name: typing.Text = ...,
        jump_url: typing.Text = ...,
        icon_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id",b"activity_id","activity_name",b"activity_name","icon_url",b"icon_url","jump_url",b"jump_url"]) -> None: ...
global___TopicActivity = TopicActivity

class TopicCapsule(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    jump_url: typing.Text
    """"""

    icon_url: typing.Text
    """"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        jump_url: typing.Text = ...,
        icon_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_url",b"icon_url","jump_url",b"jump_url","name",b"name"]) -> None: ...
global___TopicCapsule = TopicCapsule

class TopicCardItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    DYNAMIC_ITEM_FIELD_NUMBER: builtins.int
    FORD_CARD_ITEM_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    @property
    def dynamic_item(self) -> bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem:
        """"""
        pass
    @property
    def ford_card_item(self) -> global___FoldCardItem:
        """"""
        pass
    def __init__(self,
        *,
        type: builtins.int = ...,
        dynamic_item: typing.Optional[bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem] = ...,
        ford_card_item: typing.Optional[global___FoldCardItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic_item",b"dynamic_item","ford_card_item",b"ford_card_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_item",b"dynamic_item","ford_card_item",b"ford_card_item","type",b"type"]) -> None: ...
global___TopicCardItem = TopicCardItem

class TopicCardList(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOPIC_CARD_ITEMS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    TOPIC_SORT_BY_CONF_FIELD_NUMBER: builtins.int
    @property
    def topic_card_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicCardItem]:
        """"""
        pass
    offset: typing.Text
    """"""

    has_more: builtins.bool
    """"""

    @property
    def topic_sort_by_conf(self) -> global___TopicSortByConf:
        """"""
        pass
    def __init__(self,
        *,
        topic_card_items: typing.Optional[typing.Iterable[global___TopicCardItem]] = ...,
        offset: typing.Text = ...,
        has_more: builtins.bool = ...,
        topic_sort_by_conf: typing.Optional[global___TopicSortByConf] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic_sort_by_conf",b"topic_sort_by_conf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more",b"has_more","offset",b"offset","topic_card_items",b"topic_card_items","topic_sort_by_conf",b"topic_sort_by_conf"]) -> None: ...
global___TopicCardList = TopicCardList

class TopicDetailsAllReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DETAILS_TOP_INFO_FIELD_NUMBER: builtins.int
    TOPIC_ACTIVITIES_FIELD_NUMBER: builtins.int
    TOPIC_CARD_LIST_FIELD_NUMBER: builtins.int
    FUNCTIONAL_CARD_FIELD_NUMBER: builtins.int
    @property
    def details_top_info(self) -> global___DetailsTopInfo:
        """"""
        pass
    @property
    def topic_activities(self) -> global___TopicActivities:
        """"""
        pass
    @property
    def topic_card_list(self) -> global___TopicCardList:
        """"""
        pass
    @property
    def functional_card(self) -> global___FunctionalCard:
        """"""
        pass
    def __init__(self,
        *,
        details_top_info: typing.Optional[global___DetailsTopInfo] = ...,
        topic_activities: typing.Optional[global___TopicActivities] = ...,
        topic_card_list: typing.Optional[global___TopicCardList] = ...,
        functional_card: typing.Optional[global___FunctionalCard] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["details_top_info",b"details_top_info","functional_card",b"functional_card","topic_activities",b"topic_activities","topic_card_list",b"topic_card_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["details_top_info",b"details_top_info","functional_card",b"functional_card","topic_activities",b"topic_activities","topic_card_list",b"topic_card_list"]) -> None: ...
global___TopicDetailsAllReply = TopicDetailsAllReply

class TopicDetailsAllReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOPIC_ID_FIELD_NUMBER: builtins.int
    SORT_BY_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    NEED_REFRESH_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""

    sort_by: builtins.int
    """"""

    offset: typing.Text
    """"""

    page_size: builtins.int
    """"""

    local_time: builtins.int
    """"""

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
        pass
    need_refresh: builtins.int
    """"""

    source: typing.Text
    """"""

    def __init__(self,
        *,
        topic_id: builtins.int = ...,
        sort_by: builtins.int = ...,
        offset: typing.Text = ...,
        page_size: builtins.int = ...,
        local_time: builtins.int = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        need_refresh: builtins.int = ...,
        source: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_time",b"local_time","need_refresh",b"need_refresh","offset",b"offset","page_size",b"page_size","player_args",b"player_args","sort_by",b"sort_by","source",b"source","topic_id",b"topic_id"]) -> None: ...
global___TopicDetailsAllReq = TopicDetailsAllReq

class TopicDetailsFoldReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOPIC_CARD_LIST_FIELD_NUMBER: builtins.int
    FOLD_COUNT_FIELD_NUMBER: builtins.int
    @property
    def topic_card_list(self) -> global___TopicCardList:
        """"""
        pass
    fold_count: builtins.int
    """"""

    def __init__(self,
        *,
        topic_card_list: typing.Optional[global___TopicCardList] = ...,
        fold_count: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic_card_list",b"topic_card_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fold_count",b"fold_count","topic_card_list",b"topic_card_list"]) -> None: ...
global___TopicDetailsFoldReply = TopicDetailsFoldReply

class TopicDetailsFoldReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOPIC_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    FROM_SORT_BY_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""

    offset: typing.Text
    """"""

    page_size: builtins.int
    """"""

    local_time: builtins.int
    """"""

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
        pass
    from_sort_by: builtins.int
    """"""

    def __init__(self,
        *,
        topic_id: builtins.int = ...,
        offset: typing.Text = ...,
        page_size: builtins.int = ...,
        local_time: builtins.int = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        from_sort_by: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_sort_by",b"from_sort_by","local_time",b"local_time","offset",b"offset","page_size",b"page_size","player_args",b"player_args","topic_id",b"topic_id"]) -> None: ...
global___TopicDetailsFoldReq = TopicDetailsFoldReq

class TopicInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DISCUSS_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    DYNAMICS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    BACKCOLOR_FIELD_NUMBER: builtins.int
    IS_FAV_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATE_SOURCE_FIELD_NUMBER: builtins.int
    SHARE_PIC_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    SHARE_URL_FIELD_NUMBER: builtins.int
    IS_LIKE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    name: typing.Text
    """"""

    uid: builtins.int
    """"""

    view: builtins.int
    """"""

    discuss: builtins.int
    """"""

    fav: builtins.int
    """"""

    dynamics: builtins.int
    """"""

    state: builtins.int
    """"""

    jump_url: typing.Text
    """"""

    backcolor: typing.Text
    """"""

    is_fav: builtins.bool
    """"""

    description: typing.Text
    """"""

    create_source: builtins.int
    """"""

    share_pic: typing.Text
    """"""

    share: builtins.int
    """"""

    like: builtins.int
    """"""

    share_url: typing.Text
    """"""

    is_like: builtins.bool
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        name: typing.Text = ...,
        uid: builtins.int = ...,
        view: builtins.int = ...,
        discuss: builtins.int = ...,
        fav: builtins.int = ...,
        dynamics: builtins.int = ...,
        state: builtins.int = ...,
        jump_url: typing.Text = ...,
        backcolor: typing.Text = ...,
        is_fav: builtins.bool = ...,
        description: typing.Text = ...,
        create_source: builtins.int = ...,
        share_pic: typing.Text = ...,
        share: builtins.int = ...,
        like: builtins.int = ...,
        share_url: typing.Text = ...,
        is_like: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backcolor",b"backcolor","create_source",b"create_source","description",b"description","discuss",b"discuss","dynamics",b"dynamics","fav",b"fav","id",b"id","is_fav",b"is_fav","is_like",b"is_like","jump_url",b"jump_url","like",b"like","name",b"name","share",b"share","share_pic",b"share_pic","share_url",b"share_url","state",b"state","uid",b"uid","view",b"view"]) -> None: ...
global___TopicInfo = TopicInfo

class TopicSortByConf(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEFAULT_SORT_BY_FIELD_NUMBER: builtins.int
    ALL_SORT_BY_FIELD_NUMBER: builtins.int
    SHOW_SORT_BY_FIELD_NUMBER: builtins.int
    default_sort_by: builtins.int
    """"""

    @property
    def all_sort_by(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SortContent]:
        """"""
        pass
    show_sort_by: builtins.int
    """"""

    def __init__(self,
        *,
        default_sort_by: builtins.int = ...,
        all_sort_by: typing.Optional[typing.Iterable[global___SortContent]] = ...,
        show_sort_by: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_sort_by",b"all_sort_by","default_sort_by",b"default_sort_by","show_sort_by",b"show_sort_by"]) -> None: ...
global___TopicSortByConf = TopicSortByConf

class TopicThreePoint(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DYN_THREE_POINT_ITEMS_FIELD_NUMBER: builtins.int
    @property
    def dyn_three_point_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointItem]:
        """"""
        pass
    def __init__(self,
        *,
        dyn_three_point_items: typing.Optional[typing.Iterable[global___ThreePointItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_three_point_items",b"dyn_three_point_items"]) -> None: ...
global___TopicThreePoint = TopicThreePoint

class TrafficCard(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    BASE_PIC_FIELD_NUMBER: builtins.int
    BENEFIT_POINT_FIELD_NUMBER: builtins.int
    CARD_DESC_FIELD_NUMBER: builtins.int
    JUMP_TITLE_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    jump_url: typing.Text
    """"""

    icon_url: typing.Text
    """"""

    base_pic: typing.Text
    """"""

    benefit_point: typing.Text
    """"""

    card_desc: typing.Text
    """"""

    jump_title: typing.Text
    """"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        jump_url: typing.Text = ...,
        icon_url: typing.Text = ...,
        base_pic: typing.Text = ...,
        benefit_point: typing.Text = ...,
        card_desc: typing.Text = ...,
        jump_title: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_pic",b"base_pic","benefit_point",b"benefit_point","card_desc",b"card_desc","icon_url",b"icon_url","jump_title",b"jump_title","jump_url",b"jump_url","name",b"name"]) -> None: ...
global___TrafficCard = TrafficCard

class User(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAME_DESC_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""

    face: typing.Text
    """"""

    name: typing.Text
    """"""

    name_desc: typing.Text
    """"""

    def __init__(self,
        *,
        uid: builtins.int = ...,
        face: typing.Text = ...,
        name: typing.Text = ...,
        name_desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","name",b"name","name_desc",b"name_desc","uid",b"uid"]) -> None: ...
global___User = User



class ResponseCodeError(Exception):
    """请求返回 code 不为 0"""

    def __init__(self, code: int, msg: str, data: dict):
        self.code = code
        self.msg = msg
        self.data = data

    def __repr__(self) -> str:
        return f"错误码: {self.code}, 信息: {self.msg}"

    def __str__(self) -> str:
        return self.__repr__()


class AuthParamError(Exception):
    """缺少必要鉴权参数"""

    def __init__(self, *params: str):
        self.params = params

    def __repr__(self) -> str:
        return f"缺少鉴权参数 {', '.join(self.params)}"

    def __str__(self) -> str:
        return self.__repr__()


class AuthTypeError(Exception):
    """鉴权类型错误"""

    def __init__(self, auth_type: str):
        self.auth_type = auth_type

    def __repr__(self) -> str:
        return f"'{self.auth_type}' 是当前不支持的鉴权类型"

    def __str__(self) -> str:
        return self.__repr__()


class GrpcError(Exception):
    """RPC 错误"""

    def __init__(self, code: int, msg: str):
        self.code = code
        self.msg = msg

    def __repr__(self) -> str:
        return f"错误码: {self.code}, 信息: {self.msg}"

    def __str__(self) -> str:
        return self.__repr__()


if __name__ == "__main__":
    raise ValueError("test")
    raise AuthParamError("hehe", "heihei", "233")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/resource/v1/module.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/resource/v1/module.proto\x12\x18\x62ilibili.app.resource.v1\"b\n\tListReply\x12\x0b\n\x03\x65nv\x18\x01 \x01(\t\x12\x32\n\x05pools\x18\x02 \x03(\x0b\x32#.bilibili.app.resource.v1.PoolReply\x12\x14\n\x0clist_version\x18\x03 \x01(\x03\"\xe5\x01\n\x07ListReq\x12\x11\n\tpool_name\x18\x01 \x01(\t\x12\x13\n\x0bmodule_name\x18\x02 \x01(\t\x12>\n\x0cversion_list\x18\x03 \x03(\x0b\x32(.bilibili.app.resource.v1.VersionListReq\x12.\n\x03\x65nv\x18\x04 \x01(\x0e\x32!.bilibili.app.resource.v1.EnvType\x12\x0f\n\x07sys_ver\x18\x05 \x01(\x05\x12\r\n\x05scale\x18\x06 \x01(\x05\x12\x0c\n\x04\x61rch\x18\x07 \x01(\x05\x12\x14\n\x0clist_version\x18\x08 \x01(\x03\"\xbe\x03\n\x0bModuleReply\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x03\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0b\n\x03md5\x18\x04 \x01(\t\x12\x11\n\ttotal_md5\x18\x05 \x01(\t\x12:\n\tincrement\x18\x06 \x01(\x0e\x32\'.bilibili.app.resource.v1.IncrementType\x12\x0f\n\x07is_wifi\x18\x07 \x01(\x08\x12\x32\n\x05level\x18\x08 \x01(\x0e\x32#.bilibili.app.resource.v1.LevelType\x12\x10\n\x08\x66ilename\x18\t \x01(\t\x12\x11\n\tfile_type\x18\n \x01(\t\x12\x11\n\tfile_size\x18\x0b \x01(\x03\x12\x38\n\x08\x63ompress\x18\x0c \x01(\x0e\x32&.bilibili.app.resource.v1.CompressType\x12\x14\n\x0cpublish_time\x18\r \x01(\x03\x12\x0f\n\x07pool_id\x18\x0e \x01(\x03\x12\x11\n\tmodule_id\x18\x0f \x01(\x03\x12\x12\n\nversion_id\x18\x10 \x01(\x03\x12\x0f\n\x07\x66ile_id\x18\x11 \x01(\x03\x12\x11\n\tzip_check\x18\x12 \x01(\x08\"Q\n\tPoolReply\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x07modules\x18\x02 \x03(\x0b\x32%.bilibili.app.resource.v1.ModuleReply\"[\n\x0eVersionListReq\x12\x11\n\tpool_name\x18\x01 \x01(\t\x12\x36\n\x08versions\x18\x02 \x03(\x0b\x32$.bilibili.app.resource.v1.VersionReq\"2\n\nVersionReq\x12\x13\n\x0bmodule_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x03*\'\n\x0c\x43ompressType\x12\t\n\x05Unzip\x10\x00\x12\x0c\n\x08Original\x10\x01*-\n\x07\x45nvType\x12\x0b\n\x07Unknown\x10\x00\x12\x0b\n\x07Release\x10\x01\x12\x08\n\x04Test\x10\x02*+\n\rIncrementType\x12\t\n\x05Total\x10\x00\x12\x0f\n\x0bIncremental\x10\x01*9\n\tLevelType\x12\r\n\tUndefined\x10\x00\x12\x08\n\x04High\x10\x01\x12\n\n\x06Middle\x10\x02\x12\x07\n\x03Low\x10\x03\x32X\n\x06Module\x12N\n\x04List\x12!.bilibili.app.resource.v1.ListReq\x1a#.bilibili.app.resource.v1.ListReplyb\x06proto3')

_COMPRESSTYPE = DESCRIPTOR.enum_types_by_name['CompressType']
CompressType = enum_type_wrapper.EnumTypeWrapper(_COMPRESSTYPE)
_ENVTYPE = DESCRIPTOR.enum_types_by_name['EnvType']
EnvType = enum_type_wrapper.EnumTypeWrapper(_ENVTYPE)
_INCREMENTTYPE = DESCRIPTOR.enum_types_by_name['IncrementType']
IncrementType = enum_type_wrapper.EnumTypeWrapper(_INCREMENTTYPE)
_LEVELTYPE = DESCRIPTOR.enum_types_by_name['LevelType']
LevelType = enum_type_wrapper.EnumTypeWrapper(_LEVELTYPE)
Unzip = 0
Original = 1
Unknown = 0
Release = 1
Test = 2
Total = 0
Incremental = 1
Undefined = 0
High = 1
Middle = 2
Low = 3


_LISTREPLY = DESCRIPTOR.message_types_by_name['ListReply']
_LISTREQ = DESCRIPTOR.message_types_by_name['ListReq']
_MODULEREPLY = DESCRIPTOR.message_types_by_name['ModuleReply']
_POOLREPLY = DESCRIPTOR.message_types_by_name['PoolReply']
_VERSIONLISTREQ = DESCRIPTOR.message_types_by_name['VersionListReq']
_VERSIONREQ = DESCRIPTOR.message_types_by_name['VersionReq']
ListReply = _reflection.GeneratedProtocolMessageType('ListReply', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPLY,
  '__module__' : 'bilibili.app.resource.v1.module_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.v1.ListReply)
  })
_sym_db.RegisterMessage(ListReply)

ListReq = _reflection.GeneratedProtocolMessageType('ListReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTREQ,
  '__module__' : 'bilibili.app.resource.v1.module_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.v1.ListReq)
  })
_sym_db.RegisterMessage(ListReq)

ModuleReply = _reflection.GeneratedProtocolMessageType('ModuleReply', (_message.Message,), {
  'DESCRIPTOR' : _MODULEREPLY,
  '__module__' : 'bilibili.app.resource.v1.module_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.v1.ModuleReply)
  })
_sym_db.RegisterMessage(ModuleReply)

PoolReply = _reflection.GeneratedProtocolMessageType('PoolReply', (_message.Message,), {
  'DESCRIPTOR' : _POOLREPLY,
  '__module__' : 'bilibili.app.resource.v1.module_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.v1.PoolReply)
  })
_sym_db.RegisterMessage(PoolReply)

VersionListReq = _reflection.GeneratedProtocolMessageType('VersionListReq', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONLISTREQ,
  '__module__' : 'bilibili.app.resource.v1.module_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.v1.VersionListReq)
  })
_sym_db.RegisterMessage(VersionListReq)

VersionReq = _reflection.GeneratedProtocolMessageType('VersionReq', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONREQ,
  '__module__' : 'bilibili.app.resource.v1.module_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.v1.VersionReq)
  })
_sym_db.RegisterMessage(VersionReq)

_MODULE = DESCRIPTOR.services_by_name['Module']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPRESSTYPE._serialized_start=1076
  _COMPRESSTYPE._serialized_end=1115
  _ENVTYPE._serialized_start=1117
  _ENVTYPE._serialized_end=1162
  _INCREMENTTYPE._serialized_start=1164
  _INCREMENTTYPE._serialized_end=1207
  _LEVELTYPE._serialized_start=1209
  _LEVELTYPE._serialized_end=1266
  _LISTREPLY._serialized_start=67
  _LISTREPLY._serialized_end=165
  _LISTREQ._serialized_start=168
  _LISTREQ._serialized_end=397
  _MODULEREPLY._serialized_start=400
  _MODULEREPLY._serialized_end=846
  _POOLREPLY._serialized_start=848
  _POOLREPLY._serialized_end=929
  _VERSIONLISTREQ._serialized_start=931
  _VERSIONLISTREQ._serialized_end=1022
  _VERSIONREQ._serialized_start=1024
  _VERSIONREQ._serialized_end=1074
  _MODULE._serialized_start=1268
  _MODULE._serialized_end=1356
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.rpc.status_pb2
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AuthReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___AuthReq = AuthReq

class AuthResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___AuthResp = AuthResp

class FrameOption(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VEGA_ID_FIELD_NUMBER: builtins.int
    REQ_ID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    IS_ACK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ACK_ORIGIN_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    vega_id: builtins.int
    """"""

    req_id: typing.Text
    """"""

    sequence: builtins.int
    """"""

    is_ack: builtins.bool
    """"""

    @property
    def status(self) -> bilibili.rpc.status_pb2.Status:
        """"""
        pass
    ack_origin: typing.Text
    """"""

    mid: builtins.int
    """"""

    def __init__(self,
        *,
        vega_id: builtins.int = ...,
        req_id: typing.Text = ...,
        sequence: builtins.int = ...,
        is_ack: builtins.bool = ...,
        status: typing.Optional[bilibili.rpc.status_pb2.Status] = ...,
        ack_origin: typing.Text = ...,
        mid: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_origin",b"ack_origin","is_ack",b"is_ack","mid",b"mid","req_id",b"req_id","sequence",b"sequence","status",b"status","vega_id",b"vega_id"]) -> None: ...
global___FrameOption = FrameOption

class HeartbeatReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___HeartbeatReq = HeartbeatReq

class HeartbeatResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___HeartbeatResp = HeartbeatResp

class MessageAckReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VEGA_ID_FIELD_NUMBER: builtins.int
    REQ_ID_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    TARGET_PATH_FIELD_NUMBER: builtins.int
    vega_id: typing.Text
    """"""

    req_id: typing.Text
    """"""

    origin: typing.Text
    """"""

    target_path: typing.Text
    """"""

    def __init__(self,
        *,
        vega_id: typing.Text = ...,
        req_id: typing.Text = ...,
        origin: typing.Text = ...,
        target_path: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["origin",b"origin","req_id",b"req_id","target_path",b"target_path","vega_id",b"vega_id"]) -> None: ...
global___MessageAckReq = MessageAckReq

class SubscribeReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TARGET_PATHS_FIELD_NUMBER: builtins.int
    @property
    def target_paths(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TargetPath]:
        """"""
        pass
    def __init__(self,
        *,
        target_paths: typing.Optional[typing.Iterable[global___TargetPath]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_paths",b"target_paths"]) -> None: ...
global___SubscribeReq = SubscribeReq

class TargetPath(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    KEY_FIELD_NUMBER: builtins.int
    SUBS_FIELD_NUMBER: builtins.int
    key: typing.Text
    """"""

    @property
    def subs(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    def __init__(self,
        *,
        key: typing.Text = ...,
        subs: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subs",b"subs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key",b"key","subs",b"subs"]) -> None: ...
global___TargetPath = TargetPath

class VegaFrame(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OPTIONS_FIELD_NUMBER: builtins.int
    ROUTE_PATH_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    SUB_BIZ_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___FrameOption:
        """"""
        pass
    route_path: typing.Text
    """"""

    @property
    def body(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    @property
    def sub_biz(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    def __init__(self,
        *,
        options: typing.Optional[global___FrameOption] = ...,
        route_path: typing.Text = ...,
        body: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        sub_biz: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body",b"body","options",b"options","sub_biz",b"sub_biz"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body",b"body","options",b"options","route_path",b"route_path","sub_biz",b"sub_biz"]) -> None: ...
global___VegaFrame = VegaFrame



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.account.fission.v1 import fission_pb2 as bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2


class FissionStub(object):
    """Fission裂变
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Entrance = channel.unary_unary(
                '/bilibili.account.fission.v1.Fission/Entrance',
                request_serializer=bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.EntranceReq.SerializeToString,
                response_deserializer=bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.EntranceReply.FromString,
                )
        self.Window = channel.unary_unary(
                '/bilibili.account.fission.v1.Fission/Window',
                request_serializer=bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.WindowReq.SerializeToString,
                response_deserializer=bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.WindowReply.FromString,
                )


class FissionServicer(object):
    """Fission裂变
    """

    def Entrance(self, request, context):
        """活动入口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Window(self, request, context):
        """首页弹窗
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FissionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Entrance': grpc.unary_unary_rpc_method_handler(
                    servicer.Entrance,
                    request_deserializer=bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.EntranceReq.FromString,
                    response_serializer=bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.EntranceReply.SerializeToString,
            ),
            'Window': grpc.unary_unary_rpc_method_handler(
                    servicer.Window,
                    request_deserializer=bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.WindowReq.FromString,
                    response_serializer=bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.WindowReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.account.fission.v1.Fission', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Fission(object):
    """Fission裂变
    """

    @staticmethod
    def Entrance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.account.fission.v1.Fission/Entrance',
            bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.EntranceReq.SerializeToString,
            bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.EntranceReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Window(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.account.fission.v1.Fission/Window',
            bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.WindowReq.SerializeToString,
            bilibili_dot_account_dot_fission_dot_v1_dot_fission__pb2.WindowReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CommandDmOtt(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    ID_STR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    oid: builtins.int
    """"""

    mid: builtins.int
    """"""

    type: builtins.int
    """"""

    command: typing.Text
    """"""

    content: typing.Text
    """"""

    state: builtins.int
    """"""

    progress: builtins.int
    """"""

    ctime: typing.Text
    """"""

    mtime: typing.Text
    """"""

    extra: typing.Text
    """"""

    id_str: typing.Text
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        mid: builtins.int = ...,
        type: builtins.int = ...,
        command: typing.Text = ...,
        content: typing.Text = ...,
        state: builtins.int = ...,
        progress: builtins.int = ...,
        ctime: typing.Text = ...,
        mtime: typing.Text = ...,
        extra: typing.Text = ...,
        id_str: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command",b"command","content",b"content","ctime",b"ctime","extra",b"extra","id",b"id","id_str",b"id_str","mid",b"mid","mtime",b"mtime","oid",b"oid","progress",b"progress","state",b"state","type",b"type"]) -> None: ...
global___CommandDmOtt = CommandDmOtt

class CommandDmsOttReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COMMAND_DMS_OTT_FIELD_NUMBER: builtins.int
    @property
    def command_dms_ott(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommandDmOtt]:
        """"""
        pass
    def __init__(self,
        *,
        command_dms_ott: typing.Optional[typing.Iterable[global___CommandDmOtt]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command_dms_ott",b"command_dms_ott"]) -> None: ...
global___CommandDmsOttReply = CommandDmsOttReply

class CommandDmsOttReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""

    cid: builtins.int
    """"""

    mid: builtins.int
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        mid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","cid",b"cid","mid",b"mid"]) -> None: ...
global___CommandDmsOttReq = CommandDmsOttReq

class DanmakuAIFlag(google.protobuf.message.Message):
    """弹幕ai云屏蔽列表"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DM_FLAGS_FIELD_NUMBER: builtins.int
    @property
    def dm_flags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmakuFlag]:
        """弹幕ai云屏蔽条目"""
        pass
    def __init__(self,
        *,
        dm_flags: typing.Optional[typing.Iterable[global___DanmakuFlag]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dm_flags",b"dm_flags"]) -> None: ...
global___DanmakuAIFlag = DanmakuAIFlag

class DanmakuElem(google.protobuf.message.Message):
    """弹幕条目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    FONTSIZE_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    MIDHASH_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    IDSTR_FIELD_NUMBER: builtins.int
    ATTR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕dmid"""

    progress: builtins.int
    """弹幕出现位置(单位ms)"""

    mode: builtins.int
    """弹幕类型"""

    fontsize: builtins.int
    """弹幕字号"""

    color: builtins.int
    """弹幕颜色"""

    midHash: typing.Text
    """发送着mid hash"""

    content: typing.Text
    """弹幕正文"""

    ctime: builtins.int
    """发送时间"""

    weight: builtins.int
    """权重 区间:[1,10]"""

    action: typing.Text
    """动作"""

    pool: builtins.int
    """弹幕池"""

    idStr: typing.Text
    """弹幕dmid str"""

    attr: builtins.int
    """弹幕属性位(bin求AND)
    bit0:保护 bit1:直播 bit2:高赞
    """

    def __init__(self,
        *,
        id: builtins.int = ...,
        progress: builtins.int = ...,
        mode: builtins.int = ...,
        fontsize: builtins.int = ...,
        color: builtins.int = ...,
        midHash: typing.Text = ...,
        content: typing.Text = ...,
        ctime: builtins.int = ...,
        weight: builtins.int = ...,
        action: typing.Text = ...,
        pool: builtins.int = ...,
        idStr: typing.Text = ...,
        attr: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action",b"action","attr",b"attr","color",b"color","content",b"content","ctime",b"ctime","fontsize",b"fontsize","id",b"id","idStr",b"idStr","midHash",b"midHash","mode",b"mode","pool",b"pool","progress",b"progress","weight",b"weight"]) -> None: ...
global___DanmakuElem = DanmakuElem

class DanmakuFlag(google.protobuf.message.Message):
    """弹幕ai云屏蔽条目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DMID_FIELD_NUMBER: builtins.int
    FLAG_FIELD_NUMBER: builtins.int
    dmid: builtins.int
    """弹幕dmid"""

    flag: builtins.int
    """评分"""

    def __init__(self,
        *,
        dmid: builtins.int = ...,
        flag: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dmid",b"dmid","flag",b"flag"]) -> None: ...
global___DanmakuFlag = DanmakuFlag

class DanmakuFlagConfig(google.protobuf.message.Message):
    """云屏蔽配置信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REC_FLAG_FIELD_NUMBER: builtins.int
    REC_TEXT_FIELD_NUMBER: builtins.int
    REC_SWITCH_FIELD_NUMBER: builtins.int
    rec_flag: builtins.int
    """云屏蔽等级"""

    rec_text: typing.Text
    """云屏蔽文案"""

    rec_switch: builtins.int
    """云屏蔽开关"""

    def __init__(self,
        *,
        rec_flag: builtins.int = ...,
        rec_text: typing.Text = ...,
        rec_switch: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rec_flag",b"rec_flag","rec_switch",b"rec_switch","rec_text",b"rec_text"]) -> None: ...
global___DanmakuFlagConfig = DanmakuFlagConfig

class DanmuDefaultPlayerConfig(google.protobuf.message.Message):
    """弹幕默认配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PLAYER_DANMAKU_USE_DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_LEVEL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKTOP_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSCROLL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKBOTTOM_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKCOLORFUL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKREPEAT_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSPECIAL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_OPACITY_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SCALINGFACTOR_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_DOMAIN_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SPEED_FIELD_NUMBER: builtins.int
    INLINE_PLAYER_DANMAKU_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SENIOR_MODE_SWITCH_FIELD_NUMBER: builtins.int
    player_danmaku_use_default_config: builtins.bool
    """是否使用推荐弹幕设置"""

    player_danmaku_ai_recommended_switch: builtins.bool
    """是否开启智能云屏蔽"""

    player_danmaku_ai_recommended_level: builtins.int
    """智能云屏蔽等级"""

    player_danmaku_blocktop: builtins.bool
    """是否屏蔽顶端弹幕"""

    player_danmaku_blockscroll: builtins.bool
    """是否屏蔽滚动弹幕"""

    player_danmaku_blockbottom: builtins.bool
    """是否屏蔽底端弹幕"""

    player_danmaku_blockcolorful: builtins.bool
    """是否屏蔽彩色弹幕"""

    player_danmaku_blockrepeat: builtins.bool
    """是否屏蔽重复弹幕"""

    player_danmaku_blockspecial: builtins.bool
    """是否屏蔽高级弹幕"""

    player_danmaku_opacity: builtins.float
    """弹幕不透明度"""

    player_danmaku_scalingfactor: builtins.float
    """弹幕缩放比例"""

    player_danmaku_domain: builtins.float
    """弹幕显示区域"""

    player_danmaku_speed: builtins.int
    """弹幕速度"""

    inline_player_danmaku_switch: builtins.bool
    """是否开启弹幕"""

    player_danmaku_senior_mode_switch: builtins.int
    """"""

    def __init__(self,
        *,
        player_danmaku_use_default_config: builtins.bool = ...,
        player_danmaku_ai_recommended_switch: builtins.bool = ...,
        player_danmaku_ai_recommended_level: builtins.int = ...,
        player_danmaku_blocktop: builtins.bool = ...,
        player_danmaku_blockscroll: builtins.bool = ...,
        player_danmaku_blockbottom: builtins.bool = ...,
        player_danmaku_blockcolorful: builtins.bool = ...,
        player_danmaku_blockrepeat: builtins.bool = ...,
        player_danmaku_blockspecial: builtins.bool = ...,
        player_danmaku_opacity: builtins.float = ...,
        player_danmaku_scalingfactor: builtins.float = ...,
        player_danmaku_domain: builtins.float = ...,
        player_danmaku_speed: builtins.int = ...,
        inline_player_danmaku_switch: builtins.bool = ...,
        player_danmaku_senior_mode_switch: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_player_danmaku_switch",b"inline_player_danmaku_switch","player_danmaku_ai_recommended_level",b"player_danmaku_ai_recommended_level","player_danmaku_ai_recommended_switch",b"player_danmaku_ai_recommended_switch","player_danmaku_blockbottom",b"player_danmaku_blockbottom","player_danmaku_blockcolorful",b"player_danmaku_blockcolorful","player_danmaku_blockrepeat",b"player_danmaku_blockrepeat","player_danmaku_blockscroll",b"player_danmaku_blockscroll","player_danmaku_blockspecial",b"player_danmaku_blockspecial","player_danmaku_blocktop",b"player_danmaku_blocktop","player_danmaku_domain",b"player_danmaku_domain","player_danmaku_opacity",b"player_danmaku_opacity","player_danmaku_scalingfactor",b"player_danmaku_scalingfactor","player_danmaku_senior_mode_switch",b"player_danmaku_senior_mode_switch","player_danmaku_speed",b"player_danmaku_speed","player_danmaku_use_default_config",b"player_danmaku_use_default_config"]) -> None: ...
global___DanmuDefaultPlayerConfig = DanmuDefaultPlayerConfig

class DanmuPlayerConfig(google.protobuf.message.Message):
    """弹幕配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PLAYER_DANMAKU_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SWITCH_SAVE_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_USE_DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_LEVEL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKTOP_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSCROLL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKBOTTOM_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKCOLORFUL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKREPEAT_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSPECIAL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_OPACITY_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SCALINGFACTOR_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_DOMAIN_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SPEED_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_ENABLEBLOCKLIST_FIELD_NUMBER: builtins.int
    INLINE_PLAYER_DANMAKU_SWITCH_FIELD_NUMBER: builtins.int
    INLINE_PLAYER_DANMAKU_CONFIG_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_IOS_SWITCH_SAVE_FIELD_NUMBER: builtins.int
    player_danmaku_switch: builtins.bool
    """是否开启弹幕"""

    player_danmaku_switch_save: builtins.bool
    """是否记录弹幕开关设置"""

    player_danmaku_use_default_config: builtins.bool
    """是否使用推荐弹幕设置"""

    player_danmaku_ai_recommended_switch: builtins.bool
    """是否开启智能云屏蔽"""

    player_danmaku_ai_recommended_level: builtins.int
    """智能云屏蔽等级"""

    player_danmaku_blocktop: builtins.bool
    """是否屏蔽顶端弹幕"""

    player_danmaku_blockscroll: builtins.bool
    """是否屏蔽滚动弹幕"""

    player_danmaku_blockbottom: builtins.bool
    """是否屏蔽底端弹幕"""

    player_danmaku_blockcolorful: builtins.bool
    """是否屏蔽彩色弹幕"""

    player_danmaku_blockrepeat: builtins.bool
    """是否屏蔽重复弹幕"""

    player_danmaku_blockspecial: builtins.bool
    """是否屏蔽高级弹幕"""

    player_danmaku_opacity: builtins.float
    """弹幕不透明度"""

    player_danmaku_scalingfactor: builtins.float
    """弹幕缩放比例"""

    player_danmaku_domain: builtins.float
    """弹幕显示区域"""

    player_danmaku_speed: builtins.int
    """弹幕速度"""

    player_danmaku_enableblocklist: builtins.bool
    """是否开启屏蔽列表"""

    inline_player_danmaku_switch: builtins.bool
    """是否开启弹幕"""

    inline_player_danmaku_config: builtins.int
    """"""

    player_danmaku_ios_switch_save: builtins.int
    """"""

    def __init__(self,
        *,
        player_danmaku_switch: builtins.bool = ...,
        player_danmaku_switch_save: builtins.bool = ...,
        player_danmaku_use_default_config: builtins.bool = ...,
        player_danmaku_ai_recommended_switch: builtins.bool = ...,
        player_danmaku_ai_recommended_level: builtins.int = ...,
        player_danmaku_blocktop: builtins.bool = ...,
        player_danmaku_blockscroll: builtins.bool = ...,
        player_danmaku_blockbottom: builtins.bool = ...,
        player_danmaku_blockcolorful: builtins.bool = ...,
        player_danmaku_blockrepeat: builtins.bool = ...,
        player_danmaku_blockspecial: builtins.bool = ...,
        player_danmaku_opacity: builtins.float = ...,
        player_danmaku_scalingfactor: builtins.float = ...,
        player_danmaku_domain: builtins.float = ...,
        player_danmaku_speed: builtins.int = ...,
        player_danmaku_enableblocklist: builtins.bool = ...,
        inline_player_danmaku_switch: builtins.bool = ...,
        inline_player_danmaku_config: builtins.int = ...,
        player_danmaku_ios_switch_save: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_player_danmaku_config",b"inline_player_danmaku_config","inline_player_danmaku_switch",b"inline_player_danmaku_switch","player_danmaku_ai_recommended_level",b"player_danmaku_ai_recommended_level","player_danmaku_ai_recommended_switch",b"player_danmaku_ai_recommended_switch","player_danmaku_blockbottom",b"player_danmaku_blockbottom","player_danmaku_blockcolorful",b"player_danmaku_blockcolorful","player_danmaku_blockrepeat",b"player_danmaku_blockrepeat","player_danmaku_blockscroll",b"player_danmaku_blockscroll","player_danmaku_blockspecial",b"player_danmaku_blockspecial","player_danmaku_blocktop",b"player_danmaku_blocktop","player_danmaku_domain",b"player_danmaku_domain","player_danmaku_enableblocklist",b"player_danmaku_enableblocklist","player_danmaku_ios_switch_save",b"player_danmaku_ios_switch_save","player_danmaku_opacity",b"player_danmaku_opacity","player_danmaku_scalingfactor",b"player_danmaku_scalingfactor","player_danmaku_speed",b"player_danmaku_speed","player_danmaku_switch",b"player_danmaku_switch","player_danmaku_switch_save",b"player_danmaku_switch_save","player_danmaku_use_default_config",b"player_danmaku_use_default_config"]) -> None: ...
global___DanmuPlayerConfig = DanmuPlayerConfig

class DanmuPlayerDynamicConfig(google.protobuf.message.Message):
    """弹幕显示区域自动配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROGRESS_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_DOMAIN_FIELD_NUMBER: builtins.int
    progress: builtins.int
    """时间"""

    player_danmaku_domain: builtins.float
    """弹幕显示区域"""

    def __init__(self,
        *,
        progress: builtins.int = ...,
        player_danmaku_domain: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["player_danmaku_domain",b"player_danmaku_domain","progress",b"progress"]) -> None: ...
global___DanmuPlayerDynamicConfig = DanmuPlayerDynamicConfig

class DanmuPlayerViewConfig(google.protobuf.message.Message):
    """弹幕配置信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DANMUKU_DEFAULT_PLAYER_CONFIG_FIELD_NUMBER: builtins.int
    DANMUKU_PLAYER_CONFIG_FIELD_NUMBER: builtins.int
    DANMUKU_PLAYER_DYNAMIC_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def danmuku_default_player_config(self) -> global___DanmuDefaultPlayerConfig:
        """弹幕默认配置"""
        pass
    @property
    def danmuku_player_config(self) -> global___DanmuPlayerConfig:
        """弹幕用户配置"""
        pass
    @property
    def danmuku_player_dynamic_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmuPlayerDynamicConfig]:
        """弹幕显示区域自动配置列表"""
        pass
    def __init__(self,
        *,
        danmuku_default_player_config: typing.Optional[global___DanmuDefaultPlayerConfig] = ...,
        danmuku_player_config: typing.Optional[global___DanmuPlayerConfig] = ...,
        danmuku_player_dynamic_config: typing.Optional[typing.Iterable[global___DanmuPlayerDynamicConfig]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["danmuku_default_player_config",b"danmuku_default_player_config","danmuku_player_config",b"danmuku_player_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["danmuku_default_player_config",b"danmuku_default_player_config","danmuku_player_config",b"danmuku_player_config","danmuku_player_dynamic_config",b"danmuku_player_dynamic_config"]) -> None: ...
global___DanmuPlayerViewConfig = DanmuPlayerViewConfig

class DmSegMobileReply(google.protobuf.message.Message):
    """获取弹幕-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ELEMS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    AI_FLAG_FIELD_NUMBER: builtins.int
    @property
    def elems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmakuElem]:
        """弹幕列表"""
        pass
    state: builtins.int
    """是否已关闭弹幕
    0:未关闭 1:已关闭
    """

    @property
    def ai_flag(self) -> global___DanmakuAIFlag:
        """弹幕云屏蔽ai评分值"""
        pass
    def __init__(self,
        *,
        elems: typing.Optional[typing.Iterable[global___DanmakuElem]] = ...,
        state: builtins.int = ...,
        ai_flag: typing.Optional[global___DanmakuAIFlag] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ai_flag",b"ai_flag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_flag",b"ai_flag","elems",b"elems","state",b"state"]) -> None: ...
global___DmSegMobileReply = DmSegMobileReply

class DmSegMobileReq(google.protobuf.message.Message):
    """获取弹幕-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SEGMENT_INDEX_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """稿件avid/漫画epid"""

    oid: builtins.int
    """视频cid/漫画cid"""

    type: builtins.int
    """弹幕类型
    1:视频 2:漫画
    """

    segment_index: builtins.int
    """分段(6min)"""

    teenagers_mode: builtins.int
    """是否青少年模式"""

    def __init__(self,
        *,
        pid: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        segment_index: builtins.int = ...,
        teenagers_mode: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from",b"from","oid",b"oid","pid",b"pid","segment_index",b"segment_index","teenagers_mode",b"teenagers_mode","type",b"type"]) -> None: ...
global___DmSegMobileReq = DmSegMobileReq

class DmViewReply(google.protobuf.message.Message):
    """客户端弹幕元数据-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CLOSED_FIELD_NUMBER: builtins.int
    MASK_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    SPECIAL_DMS_FIELD_NUMBER: builtins.int
    AI_FLAG_FIELD_NUMBER: builtins.int
    PLAYER_CONFIG_FIELD_NUMBER: builtins.int
    SEND_BOX_STYLE_FIELD_NUMBER: builtins.int
    ALLOW_FIELD_NUMBER: builtins.int
    CHECK_BOX_FIELD_NUMBER: builtins.int
    CHECK_BOX_SHOW_MSG_FIELD_NUMBER: builtins.int
    TEXT_PLACEHOLDER_FIELD_NUMBER: builtins.int
    INPUT_PLACEHOLDER_FIELD_NUMBER: builtins.int
    closed: builtins.bool
    """是否已关闭弹幕
    0:未关闭 1:已关闭
    """

    @property
    def mask(self) -> global___VideoMask:
        """智能防挡弹幕蒙版信息"""
        pass
    @property
    def subtitle(self) -> global___VideoSubtitle:
        """视频字幕"""
        pass
    @property
    def special_dms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """高级弹幕专包url(bfs)"""
        pass
    @property
    def ai_flag(self) -> global___DanmakuFlagConfig:
        """云屏蔽配置信息"""
        pass
    @property
    def player_config(self) -> global___DanmuPlayerViewConfig:
        """弹幕配置信息"""
        pass
    send_box_style: builtins.int
    """弹幕发送框样式"""

    allow: builtins.bool
    """是否允许"""

    check_box: typing.Text
    """check box 是否展示"""

    check_box_show_msg: typing.Text
    """check box 展示文本"""

    text_placeholder: typing.Text
    """展示文案"""

    input_placeholder: typing.Text
    """弹幕输入框文案"""

    def __init__(self,
        *,
        closed: builtins.bool = ...,
        mask: typing.Optional[global___VideoMask] = ...,
        subtitle: typing.Optional[global___VideoSubtitle] = ...,
        special_dms: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ai_flag: typing.Optional[global___DanmakuFlagConfig] = ...,
        player_config: typing.Optional[global___DanmuPlayerViewConfig] = ...,
        send_box_style: builtins.int = ...,
        allow: builtins.bool = ...,
        check_box: typing.Text = ...,
        check_box_show_msg: typing.Text = ...,
        text_placeholder: typing.Text = ...,
        input_placeholder: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ai_flag",b"ai_flag","mask",b"mask","player_config",b"player_config","subtitle",b"subtitle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_flag",b"ai_flag","allow",b"allow","check_box",b"check_box","check_box_show_msg",b"check_box_show_msg","closed",b"closed","input_placeholder",b"input_placeholder","mask",b"mask","player_config",b"player_config","send_box_style",b"send_box_style","special_dms",b"special_dms","subtitle",b"subtitle","text_placeholder",b"text_placeholder"]) -> None: ...
global___DmViewReply = DmViewReply

class DmViewReq(google.protobuf.message.Message):
    """客户端弹幕元数据-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    IS_HARD_BOOT_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """稿件avid/漫画epid"""

    oid: builtins.int
    """视频cid/漫画cid"""

    type: builtins.int
    """弹幕类型
    1:视频 2:漫画
    """

    spmid: typing.Text
    """页面spm"""

    is_hard_boot: builtins.int
    """是否冷启"""

    def __init__(self,
        *,
        pid: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        spmid: typing.Text = ...,
        is_hard_boot: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from",b"from","is_hard_boot",b"is_hard_boot","oid",b"oid","pid",b"pid","spmid",b"spmid","type",b"type"]) -> None: ...
global___DmViewReq = DmViewReq

class SubtitleItem(google.protobuf.message.Message):
    """单个字幕信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    ID_STR_FIELD_NUMBER: builtins.int
    LAN_FIELD_NUMBER: builtins.int
    LAN_DOC_FIELD_NUMBER: builtins.int
    SUBTITLE_URL_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """字幕id"""

    id_str: typing.Text
    """字幕id str"""

    lan: typing.Text
    """字幕语言代码"""

    lan_doc: typing.Text
    """字幕语言"""

    subtitle_url: typing.Text
    """字幕文件url"""

    @property
    def author(self) -> global___UserInfo:
        """字幕作者信息"""
        pass
    def __init__(self,
        *,
        id: builtins.int = ...,
        id_str: typing.Text = ...,
        lan: typing.Text = ...,
        lan_doc: typing.Text = ...,
        subtitle_url: typing.Text = ...,
        author: typing.Optional[global___UserInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author",b"author"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author",b"author","id",b"id","id_str",b"id_str","lan",b"lan","lan_doc",b"lan_doc","subtitle_url",b"subtitle_url"]) -> None: ...
global___SubtitleItem = SubtitleItem

class UserInfo(google.protobuf.message.Message):
    """字幕作者信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""

    name: typing.Text
    """用户昵称"""

    sex: typing.Text
    """用户性别"""

    face: typing.Text
    """用户头像url"""

    sign: typing.Text
    """用户签名"""

    rank: builtins.int
    """用户等级"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        sex: typing.Text = ...,
        face: typing.Text = ...,
        sign: typing.Text = ...,
        rank: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","mid",b"mid","name",b"name","rank",b"rank","sex",b"sex","sign",b"sign"]) -> None: ...
global___UserInfo = UserInfo

class VideoMask(google.protobuf.message.Message):
    """智能防挡弹幕蒙版信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CID_FIELD_NUMBER: builtins.int
    PLAT_FIELD_NUMBER: builtins.int
    FPS_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    MASK_URL_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """视频cid"""

    plat: builtins.int
    """平台
    0:web端 1:客户端
    """

    fps: builtins.int
    """帧率"""

    time: builtins.int
    """间隔时间"""

    mask_url: typing.Text
    """蒙版url"""

    def __init__(self,
        *,
        cid: builtins.int = ...,
        plat: builtins.int = ...,
        fps: builtins.int = ...,
        time: builtins.int = ...,
        mask_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","fps",b"fps","mask_url",b"mask_url","plat",b"plat","time",b"time"]) -> None: ...
global___VideoMask = VideoMask

class VideoSubtitle(google.protobuf.message.Message):
    """视频字幕信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LAN_FIELD_NUMBER: builtins.int
    LANDOC_FIELD_NUMBER: builtins.int
    SUBTITLES_FIELD_NUMBER: builtins.int
    lan: typing.Text
    """视频原语言代码"""

    lanDoc: typing.Text
    """视频原语言"""

    @property
    def subtitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubtitleItem]:
        """视频字幕列表"""
        pass
    def __init__(self,
        *,
        lan: typing.Text = ...,
        lanDoc: typing.Text = ...,
        subtitles: typing.Optional[typing.Iterable[global___SubtitleItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lan",b"lan","lanDoc",b"lanDoc","subtitles",b"subtitles"]) -> None: ...
global___VideoSubtitle = VideoSubtitle



# TODO 对这部分重构
from typing import Union

table = "fZodR9XQDSUm21yCkr6zBqiveYah8bt4xsWpHnJE7jL5VG3guMTKNPAwcF"
tr = {}
for i in range(58):
    tr[table[i]] = i
s = [11, 10, 3, 8, 4, 6]
xor = 177451812
add = 8728348608


def av2bv(aid: Union[int, str]) -> str:
    # TODO 没考虑 av 开头的字符串
    aid = int(aid)
    aid = (aid ^ xor) + add
    r = list("BV1  4 1 7  ")
    for i in range(6):
        r[s[i]] = table[aid // 58**i % 58]
    return "".join(r)


def bv2av(bid: str) -> int:
    r = 0
    for i in range(6):
        r += tr[bid[s[i]]] * 58**i
    return (r - add) ^ xor
